# GeoDock

Official repository for [GeoDock](https://www.biorxiv.org/content/10.1101/2023.06.29.547134v1): Flexible Protein-Protein Docking with a Multi-Track Iterative Transformer.

Try protein docking in [Google Colab](https://colab.research.google.com/github/Graylab/GeoDock/blob/main/GeoDock.ipynb)

## Bug reports

If you run into any problems while using GeoDock, please create a [Github issue](https://github.com/Graylab/GeoDock/issues) with a description of the problem and the steps to reproduce it.

## Citing this work

```bibtex
@article{chu_flexible_2023,
        title = {Flexible {Protein}-{Protein} {Docking} with a {Multi}-{Track} {Iterative} {Transformer}},
        author = {Chu, Lee-Shin and Ruffolo, Jeffrey A and Harmalkar, Ameya and Gray, Jeffrey J}
        url = {https://www.biorxiv.org/content/early/2023/07/01/2023.06.29.547134},
        doi = {10.1101/2023.06.29.547134},

```
